import pTryEach from 'p-try-each';
import { render } from './dir-view/index.js';
const INDEX_HTML_FILES = [
  'index.html',
  'index.htm',
  'index.shtml'
];
const findIndexFile = (ipfs, path) => {
  return pTryEach(INDEX_HTML_FILES.map(file => {
    return async () => {
      const stats = await ipfs.files.stat(`${ path }/${ file }`);
      return {
        name: file,
        cid: stats.cid
      };
    };
  }));
};
export const directory = async (ipfs, path, cid) => {
  try {
    const res = await findIndexFile(ipfs, path);
    return [{ Name: res.name }];
  } catch (err) {
    if (err.message.includes('does not exist')) {
      const result = await ipfs.dag.get(cid);
      return render(path, result.value.Links);
    }
    throw err;
  }
};
export const cid = async (ipfs, path) => {
  const stats = await ipfs.files.stat(path);
  if (stats.type.includes('directory')) {
    const err = Object.assign(new Error('This dag node is a directory'), {
      cid: stats.cid,
      fileName: stats.fileName,
      dagDirType: stats.type
    });
    throw err;
  }
  return { cid: stats.cid };
};